@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
+/*  Copyright (C) 2009, 2010, 2011, 2012, 2013 The Free Software Foundation  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -134,6 +134,8 @@ on_combobox_language_changed (GtkComboBox *cmb, gpointer user_data)
 	active = gtk_combo_box_get_active (cmb);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (get_wg ("combobox_top10_language")), active);
 	callbacks_shield_set (FALSE);
+
+	on_combobox_stat_module_changed (GTK_COMBO_BOX (get_wg ("combobox_stat_module")), (gpointer) -1);
 }
 
 G_MODULE_EXPORT void
@@ -141,8 +143,13 @@ on_combobox_kbd_country_changed (GtkComboBox *cmb, gpointer user_data)
 {
 	if (callbacks_shield)
 		return;
+	if (keyb_get_name ()) accur_close ();
 	keyb_set_combo_kbd_variant ("combobox_kbd_country", "combobox_kbd_variant");
+	accur_init ();
 	main_preferences_set_string ("tutor", "keyboard", keyb_get_name ());
+
+	on_combobox_stat_module_changed (GTK_COMBO_BOX (get_wg ("combobox_stat_module")), (gpointer) -1);
+
 	//g_message ("kbd_country_changed: %s", keyb_get_name ());
 }
 
@@ -159,10 +166,15 @@ on_combobox_kbd_variant_changed (GtkComboBox *cmb, gpointer user_data)
 		keyb_mode_edit ();
 	else
 	{
+		if (keyb_get_name ()) accur_close ();
 		keyb_update_from_variant ("combobox_kbd_country", "combobox_kbd_variant");
+		accur_init ();
 		main_preferences_set_string ("tutor", "keyboard", keyb_get_name ());
 	}
 	g_free (tmp);
+
+	on_combobox_stat_module_changed (GTK_COMBO_BOX (get_wg ("combobox_stat_module")), (gpointer) -1);
+
 	//g_message ("kbd_variant_changed: %s", keyb_get_name ());
 }
 
@@ -1267,9 +1279,11 @@ on_button_hints_close_clicked (GtkButton *but, gpointer user_data)
 G_MODULE_EXPORT void
 on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 {
-	static gboolean init = TRUE;
+	static gchar *stat_title = NULL;
+	gchar *win_title;
 	gint i;
 	gchar *tmp;
+	GtkWindow *win;
 
 	if (callbacks_shield == TRUE)
 		return;
@@ -1277,13 +1291,15 @@ on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 	if (gtk_combo_box_get_active (cmb) < 0)
 		return;
 
-	if (init)
+	win = GTK_WINDOW (get_wg ("window_stat"));
+	if (stat_title == NULL)
 	{
 		plot_initialize ();
-		init = FALSE;
+		stat_title = g_strdup (gtk_window_get_title (win));
 	}
 
-	tutor_init (gtk_combo_box_get_active (cmb));
+	if (user_data == NULL)
+		tutor_init (gtk_combo_box_get_active (cmb));
 
 	callbacks_shield_set (TRUE);
 	for (i = 0; i < 4; i++)
@@ -1294,9 +1310,14 @@ on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 	tmp = g_strdup_printf ("%s %s", _("Speed"), _("(WPM)"));
 	gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 1, tmp);
 	g_free (tmp);
+
 	switch (gtk_combo_box_get_active (cmb))
 	{
+	case 0:
+		win_title = g_strdup_printf ("%s (%s)", stat_title, keyb_mode_get_name ());
+		break;
 	case 1:
+		win_title = g_strdup_printf ("%s (%s)", stat_title, keyb_mode_get_name ());
 		tmp = g_strdup_printf ("%s", _("Errors"));
 		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 2, tmp);
 		g_free (tmp);
@@ -1304,7 +1325,11 @@ on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 3, tmp);
 		g_free (tmp);
 		break;
+	case 2:
+		win_title = g_strdup_printf ("%s (%s)", stat_title, trans_get_current_language ());
+		break;
 	case 3:
+		win_title = g_strdup_printf ("%s (%s)", stat_title, trans_get_current_language ());
 		tmp = g_strdup_printf ("%s (%%)", _("Fluidity"));
 		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 2, tmp);
 		g_free (tmp);
@@ -1312,10 +1337,15 @@ on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 3, tmp);
 		g_free (tmp);
 		break;
+	default:
+		win_title = g_strdup (stat_title);
 	}
+
 	gtk_combo_box_set_active (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 0);
 	callbacks_shield_set (FALSE);
 
+	gtk_window_set_title (win, win_title);
+	g_free (win_title);
 	plot_draw_chart (1);
 }
 
