@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
+/*  Copyright (C) 2009, 2010, 2011, 2012, 2013 The Free Software Foundation  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -359,6 +359,25 @@ keyb_set_chars ()
 	}
 }
 
+/**********************************************************************
+ * Test if chr belongs to the current key set
+ */
+gboolean keyb_is_inset (gunichar chr)
+{
+	register gint i, j;
+
+	for (i = 0; i < 4; i++)
+		for (j = 0; j <= KEY_LINE_LEN; j++)
+			if (chr == keyb.lochars[i][j])
+				return (TRUE);
+
+	for (i = 0; i < 4; i++)
+		for (j = 0; j <= KEY_LINE_LEN; j++)
+			if (chr == keyb.upchars[i][j])
+				return (TRUE);
+	return (FALSE);
+}
+
 /**********************************************************************
  * Test if chr is a vowel 
  */
@@ -813,7 +832,7 @@ keyb_set_combo_kbd_variant (gchar *cmb_country, gchar *cmb_variant)
 
 	callbacks_shield_set (TRUE);
 
-	/* Clear the combo
+	/* Clear the combo variant
 	 */
 	cmb = GTK_COMBO_BOX (get_wg (cmb_variant));
 	tmd = gtk_combo_box_get_model (cmb);
@@ -1241,23 +1260,36 @@ keyb_intro_step (gint step)
 		keyb.intro_step = 0;
 }
 
-void
-keyb_mode_intro ()
+gchar *
+keyb_mode_get_name ()
 {
 	gchar *country;
 	gchar *variant;
+	static gchar *kbname = NULL;
+
+	if (kbname != NULL)
+		g_free (kbname);
+
+	country = gtk_combo_box_get_active_text (GTK_COMBO_BOX (get_wg ("combobox_kbd_country")));
+	variant = gtk_combo_box_get_active_text (GTK_COMBO_BOX (get_wg ("combobox_kbd_variant")));
+	kbname = g_strdup_printf ("%s - %s", country, variant);
+	g_free (country);
+	g_free (variant);
+
+	return (kbname);
+}
+
+void
+keyb_mode_intro ()
+{
 	gchar *tit;
 
 	keyb_update_virtual_layout ();
 	gtk_widget_hide (get_wg ("window_hints"));
 	keyb_edit_none ();
 
-	country = gtk_combo_box_get_active_text (GTK_COMBO_BOX (get_wg ("combobox_kbd_country")));
-	variant = gtk_combo_box_get_active_text (GTK_COMBO_BOX (get_wg ("combobox_kbd_variant")));
-	tit = g_strdup_printf ("%s - %s - %s [%s]", _("Introduction"), _("Keyboard"), country, variant);
+	tit = g_strdup_printf ("%s - %s: %s", _("Introduction"), _("Keyboard"), keyb_mode_get_name ());
 	gtk_window_set_title (get_win ("window_keyboard"), tit);
-	g_free (country);
-	g_free (variant);
 	g_free (tit);
 
 	gtk_window_set_resizable (get_win ("window_keyboard"), TRUE);
@@ -1284,20 +1316,14 @@ keyb_mode_intro ()
 void
 keyb_mode_hint ()
 {
-	gchar *country;
-	gchar *variant;
 	gchar *tit;
 
 	keyb_update_virtual_layout ();
 	gtk_widget_hide (get_wg ("window_hints"));
 	keyb_edit_none ();
 
-	country = gtk_combo_box_get_active_text (GTK_COMBO_BOX (get_wg ("combobox_kbd_country")));
-	variant = gtk_combo_box_get_active_text (GTK_COMBO_BOX (get_wg ("combobox_kbd_variant")));
-	tit = g_strdup_printf ("%s - %s [%s]", _("Keyboard"), country, variant);
+	tit = g_strdup_printf ("%s: %s", _("Keyboard"), keyb_mode_get_name ());
 	gtk_window_set_title (get_win ("window_keyboard"), tit);
-	g_free (country);
-	g_free (variant);
 	g_free (tit);
 
 	gtk_window_set_resizable (get_win ("window_keyboard"), FALSE);
