@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
+/*  Copyright (C) 2009, 2010, 2011, 2012, 2013 The Free Software Foundation  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -34,6 +34,8 @@
 #include "tutor.h"
 #include "basic.h"
 #include "accuracy.h"
+#include "keyboard.h"
+#include "translation.h"
 #include "plot.h"
 
 static struct
@@ -83,6 +85,7 @@ gchar date[DATA_POINTS+1][20];
 gchar hour[DATA_POINTS+1][20];
 gint nchars[DATA_POINTS+1];
 gchar lesson[DATA_POINTS+1][299];
+gchar language[DATA_POINTS+1][80];
 glong n_points;
 gint plot_type;
 
@@ -282,8 +285,9 @@ plot_draw_chart (gint field)
 {
 	gint i;
 	gint lesson_n;
-	gchar *tmp_locale;
+	gchar *kb_name;
 	gchar *tmp_name;
+	gchar *tmp_locale;
 	gchar tmp_str[2000];
 	FILE *fh;
 	GdkColor color, color2, color3;
@@ -347,7 +351,19 @@ plot_draw_chart (gint field)
 		return;
 	}
 
-	/* Reads the first line (header)
+	/* Change to "C" locale
+	 */
+	tmp_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+	if (tmp_locale != NULL)
+		setlocale (LC_NUMERIC, "C");
+
+	/* Keyboard names are compared without spaces (may be needed for custom files)
+	 */
+	kb_name = g_strdup (keyb_get_name ());
+	for (i=0; kb_name[i]; i++)
+		kb_name[i] = (kb_name[i] == ' ') ? '_' : kb_name[i];
+
+	/* Read the first line (header)
 	 */
 	if (!fgets (tmp_str, 2000, fh))
 	{
@@ -357,51 +373,40 @@ plot_draw_chart (gint field)
 		return;
 	}
 
-	/* Changing to "C" locale
-	 */
-	tmp_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
-	if (tmp_locale != NULL)
-		setlocale (LC_NUMERIC, "C");
-
-	/* Reads the first DATA_POINTS points
+	/* Read the first DATA_POINTS points
 	 */
 	for (i = 0; i < DATA_POINTS; i++)
 		plot.data.y[i] = -1000;
-
 	i = 0;
 	while (1)
 	{
 		gint itens;
 
 		if (field < 4)
-			itens = fscanf (fh, "%f%f%f%s%s", &accur[i], &velo[i], &fluid[i], date[i],
-					hour[i]);
+			itens = fscanf (fh, "%f%f%f%s%s%s%s", &accur[i], &velo[i], &fluid[i],
+				       	date[i], hour[i], lesson[i], language[i]);
 		else
-			itens = fscanf (fh, "%f%s%s%i", &score[i], date[i], hour[i], &nchars[i]);
+			itens = fscanf (fh, "%f%s%s%i%s", &score[i], date[i], hour[i], &nchars[i], language[i]);
 
-		if (itens != 5 && field < 4)
+		if (field < 4 && itens != 7)
 			break;
-		else if (itens != 4 && field == 4)
+		else if (field == 4 && itens != 5)
 			break;
 
-		if (fgets (lesson[i], 299, fh) == NULL)
-			break;
-
-		if (strlen (lesson[i]) == 299)
-		{
-			if (field < 4)
-				g_warning
-					("file name of custom lesson too long in line %i of %s: "
-					 "the limit is 299 characters.", i, tmp_name);
-			else
-				g_warning
-					("language name too long in line %i of %s: "
-					 "the limit is 299 characters.", i, tmp_name);
-		}
-
 		//plot_clip_data (i);
 
-		if (tutor_get_type () == TT_BASIC && g_ascii_strtoll (lesson[i], NULL, 10) != lesson_n)
+		if (tutor_get_type () == TT_BASIC)
+		{
+			if (g_ascii_strtoll (lesson[i], NULL, 10) != lesson_n)
+				continue;
+			if (strcmp (language[i], kb_name) != 0)
+				continue;
+		}
+		if (tutor_get_type () == TT_ADAPT && strcmp (lesson[i], kb_name) != 0)
+			continue;
+		if (tutor_get_type () == TT_VELO && strcmp (language[i], trans_get_current_language ()) != 0)
+			continue;
+		if (tutor_get_type () == TT_FLUID && strcmp (language[i], trans_get_current_language ()) != 0)
 			continue;
 		switch (field)
 		{
@@ -422,40 +427,37 @@ plot_draw_chart (gint field)
 			break;
 	}
 
-	/* Reads until the end, keeping the last DATA_POINTS points 
+	/* Read until the end, keeping the last DATA_POINTS points 
 	 */
 	while (1)
 	{
 		gint itens;
 
 		if (field < 4)
-			itens = fscanf (fh, "%f%f%f%s%s", &accur[i], &velo[i], &fluid[i], date[i],
-					hour[i]);
+			itens = fscanf (fh, "%f%f%f%s%s%s%s", &accur[i], &velo[i], &fluid[i],
+				       	date[i], hour[i], lesson[i], language[i]);
 		else
-			itens = fscanf (fh, "%f%s%s%i", &score[i], date[i], hour[i], &nchars[i]);
+			itens = fscanf (fh, "%f%s%s%i%s", &score[i], date[i], hour[i], &nchars[i], language[i]);
 
-		if (itens != 5 && field < 4)
+		if (field < 4 && itens != 7)
 			break;
-		else if (itens != 4 && field == 4)
+		else if (field == 4 && itens != 5)
 			break;
 
-		if (fgets (lesson[i], 299, fh) == NULL)
-			break;
-		if (strlen (lesson[i]) == 299)
-		{
-			if (field < 4)
-				g_warning
-					("file name of custom lesson too long in line %i of %s: "
-					 "the limit is 299 characters.", i, tmp_name);
-			else
-				g_warning
-					("language name too long in line %i of %s: "
-					 "the limit is 299 characters.", i, tmp_name);
-		}
-
 		//plot_clip_data (i);
 
-		if (tutor_get_type () == TT_BASIC && g_ascii_strtoll (lesson[i], NULL, 10) != lesson_n)
+		if (tutor_get_type () == TT_BASIC)
+		{
+			if (g_ascii_strtoll (lesson[i], NULL, 10) != lesson_n)
+				continue;
+			if (strcmp (language[i], kb_name) != 0)
+				continue;
+		}
+		if (tutor_get_type () == TT_ADAPT && strcmp (lesson[i], kb_name) != 0)
+			continue;
+		if (tutor_get_type () == TT_VELO && strcmp (language[i], trans_get_current_language ()) != 0)
+			continue;
+		if (tutor_get_type () == TT_FLUID && strcmp (language[i], trans_get_current_language ()) != 0)
 			continue;
 		for (i = 0; i < DATA_POINTS - 1; i++)
 		{
@@ -484,6 +486,7 @@ plot_draw_chart (gint field)
 		i = DATA_POINTS;
 	}
 	fclose (fh);
+	g_free (kb_name);
 	g_free (tmp_name);
 
 	/* Coming back to the right locale
