@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
+/*  Copyright (C) 2009, 2010, 2011, 2012, 2013 The Free Software Foundation  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -906,8 +906,12 @@ tutor_calc_stats ()
 		if (!(fh = (FILE *) g_fopen (tmp_name, "r")))
 		{
 			fh = (FILE *) g_fopen (tmp_name, "w");
-			fprintf (fh,
-				 "Accuracy\tVelocity\tFluidness\tDate\tHour\tLesson\tLanguage\n");
+			if (tutor.type == TT_BASIC)
+				fprintf (fh, "Accuracy\tVelocity\tFluidness\tDate\tHour\tLesson\tKeyboard\n");
+			else if (tutor.type == TT_ADAPT)
+				fprintf (fh, "Accuracy\tVelocity\tFluidness\tDate\tHour\tKeyboard\tLanguage\n");
+			else
+				fprintf (fh, "Accuracy\tVelocity\tFluidness\tDate\tHour\tLesson\tLanguage\n");
 		}
 		else
 		{
@@ -929,16 +933,38 @@ tutor_calc_stats ()
 				fprintf (fh, "%2.2i\t", basic_get_lesson ());
 				break;
 			case TT_ADAPT:
-				fprintf (fh, "%s\t", _("Default"));
+				tmp = g_strdup (keyb_get_name ());
+				for (i=0; tmp[i]; i++)
+					tmp[i] = (tmp[i] == ' ') ? '_' : tmp[i];
+				fprintf (fh, "%s\t", tmp);
+				g_free (tmp);
 				break;
 			case TT_VELO:
-				fprintf (fh, "%s\t", velo_get_dict_name ());
+				tmp = g_strdup (velo_get_dict_name ());
+				for (i=0; tmp[i]; i++)
+					tmp[i] = (tmp[i] == ' ') ? '_' : tmp[i];
+				fprintf (fh, "%s\t", tmp);
+				g_free (tmp);
 				break;
 			case TT_FLUID:
-				fprintf (fh, "%s\t", fluid_get_paragraph_name ());
+				tmp = g_strdup (fluid_get_paragraph_name ());
+				for (i=0; tmp[i]; i++)
+					tmp[i] = (tmp[i] == ' ') ? '_' : tmp[i];
+				fprintf (fh, "%s\t", tmp);
+				g_free (tmp);
+				break;
 			}
 
-			fprintf (fh, "%s\n", trans_get_current_language ());
+			if (tutor.type == TT_BASIC)
+			{
+				tmp = g_strdup (keyb_get_name ());
+				for (i=0; tmp[i]; i++)
+					tmp[i] = (tmp[i] == ' ') ? '_' : tmp[i];
+				fprintf (fh, "%s\n", tmp );
+				g_free (tmp);
+			}
+			else
+				fprintf (fh, "%s\n", trans_get_current_language ());
 
 			fclose (fh);
 		}
